@@ -2,137 +2,216 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="tr">
 <context>
-    <name>mxremastercc</name>
+    <name>MainWindow</name>
     <message>
-        <location filename="../mxremastercc.ui" line="14"/>
+        <location filename="../mainwindow.ui" line="14"/>
         <source>MX Remastercc</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="64"/>
+        <location filename="../mainwindow.ui" line="64"/>
         <source>Persistence</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="81"/>
+        <location filename="../mainwindow.ui" line="81"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="133"/>
+        <location filename="../mainwindow.ui" line="133"/>
         <source>Display help </source>
-        <translation>Yardımı görüntüle</translation>
+        <translation type="unfinished">Yardımı görüntüle</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="136"/>
+        <location filename="../mainwindow.ui" line="136"/>
         <source>Help</source>
-        <translation>Yardım</translation>
+        <translation type="unfinished">Yardım</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="143"/>
+        <location filename="../mainwindow.ui" line="143"/>
         <source>Alt+H</source>
-        <translation>Alt+H</translation>
+        <translation type="unfinished">Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="175"/>
+        <location filename="../mainwindow.ui" line="175"/>
         <source>About this application</source>
-        <translation>Uygulama hakkında</translation>
+        <translation type="unfinished">Uygulama hakkında</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="178"/>
+        <location filename="../mainwindow.ui" line="178"/>
         <source>About...</source>
-        <translation>Hakkında...</translation>
+        <translation type="unfinished">Hakkında...</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="185"/>
+        <location filename="../mainwindow.ui" line="185"/>
         <source>Alt+B</source>
-        <translation>Alt+B</translation>
+        <translation type="unfinished">Alt+B</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="217"/>
+        <location filename="../mainwindow.ui" line="217"/>
         <source>Quit application</source>
-        <translation>Uygulamadan çık</translation>
+        <translation type="unfinished">Uygulamadan çık</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="220"/>
+        <location filename="../mainwindow.ui" line="220"/>
         <source>Close</source>
-        <translation>Kapat</translation>
+        <translation type="unfinished">Kapat</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="227"/>
+        <location filename="../mainwindow.ui" line="227"/>
         <source>Alt+N</source>
-        <translation>Alt+N</translation>
+        <translation type="unfinished">Alt+N</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="264"/>
+        <location filename="../mainwindow.ui" line="264"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="274"/>
+        <location filename="../mainwindow.ui" line="274"/>
         <source>Remaster</source>
-        <translation>Yeniden düzenle</translation>
+        <translation type="unfinished">Yeniden düzenle</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="300"/>
+        <location filename="../mainwindow.ui" line="301"/>
         <source>Save root persistence</source>
-        <translation>kalıcı root&apos;u kaydedin</translation>
+        <translation type="unfinished">kalıcı root&apos;u kaydedin</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="313"/>
+        <location filename="../mainwindow.ui" line="315"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.ui" line="323"/>
+        <location filename="../mainwindow.ui" line="325"/>
         <source>Configure live persistence</source>
-        <translation>live persistence Yapılandırma</translation>
+        <translation type="unfinished">live persistence Yapılandırma</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="53"/>
-        <location filename="../mxremastercc.cpp" line="96"/>
+        <location filename="../mainwindow.cpp" line="54"/>
+        <location filename="../mainwindow.cpp" line="97"/>
         <source>MX Remaster Control Center</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="95"/>
+        <location filename="../mainwindow.cpp" line="96"/>
         <source>About MX Remaster Control Center</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="96"/>
+        <location filename="../mainwindow.cpp" line="97"/>
         <source>Version: </source>
-        <translation>Sürüm</translation>
+        <translation type="unfinished">Sürüm</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="97"/>
+        <location filename="../mainwindow.cpp" line="98"/>
         <source>This program provides access to different remaster and persistence tools in MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Bu program MX Linux&apos;taki farklı yeniden düzenleme ve kalıcı yapma araçlarına erişim sağlar</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="99"/>
+        <location filename="../mainwindow.cpp" line="100"/>
         <source>Copyright (c) MX Linux</source>
-        <translation>Copyright (c) MX Linux</translation>
+        <translation type="unfinished">Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="101"/>
         <source>License</source>
-        <translation>Ruhsat</translation>
+        <translation type="unfinished">Ruhsat</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="101"/>
+        <location filename="../mainwindow.cpp" line="102"/>
         <source>Changelog</source>
-        <translation>Değişim günlüğü</translation>
+        <translation type="unfinished">Değişim günlüğü</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="102"/>
+        <location filename="../mainwindow.cpp" line="103"/>
         <source>Cancel</source>
-        <translation>İptal</translation>
+        <translation type="unfinished">İptal</translation>
     </message>
     <message>
-        <location filename="../mxremastercc.cpp" line="118"/>
+        <location filename="../mainwindow.cpp" line="119"/>
         <source>&amp;Close</source>
-        <translation>&amp;Kapat</translation>
+        <translation type="unfinished">&amp;Kapat</translation>
+    </message>
+</context>
+<context>
+    <name>mxremastercc</name>
+    <message>
+        <source>Display help </source>
+        <translation type="vanished">Yardımı görüntüle</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation type="vanished">Yardım</translation>
+    </message>
+    <message>
+        <source>Alt+H</source>
+        <translation type="vanished">Alt+H</translation>
+    </message>
+    <message>
+        <source>About this application</source>
+        <translation type="vanished">Uygulama hakkında</translation>
+    </message>
+    <message>
+        <source>About...</source>
+        <translation type="vanished">Hakkında...</translation>
+    </message>
+    <message>
+        <source>Alt+B</source>
+        <translation type="vanished">Alt+B</translation>
+    </message>
+    <message>
+        <source>Quit application</source>
+        <translation type="vanished">Uygulamadan çık</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation type="vanished">Kapat</translation>
+    </message>
+    <message>
+        <source>Alt+N</source>
+        <translation type="vanished">Alt+N</translation>
+    </message>
+    <message>
+        <source>Remaster</source>
+        <translation type="vanished">Yeniden düzenle</translation>
+    </message>
+    <message>
+        <source>Save root persistence</source>
+        <translation type="vanished">kalıcı root&apos;u kaydedin</translation>
+    </message>
+    <message>
+        <source>Configure live persistence</source>
+        <translation type="vanished">live persistence Yapılandırma</translation>
+    </message>
+    <message>
+        <source>Version: </source>
+        <translation type="vanished">Sürüm</translation>
+    </message>
+    <message>
+        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
+        <translation type="vanished">Bu program MX Linux&apos;taki farklı yeniden düzenleme ve kalıcı yapma araçlarına erişim sağlar</translation>
+    </message>
+    <message>
+        <source>Copyright (c) MX Linux</source>
+        <translation type="vanished">Copyright (c) MX Linux</translation>
+    </message>
+    <message>
+        <source>License</source>
+        <translation type="vanished">Ruhsat</translation>
+    </message>
+    <message>
+        <source>Changelog</source>
+        <translation type="vanished">Değişim günlüğü</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="vanished">İptal</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="vanished">&amp;Kapat</translation>
     </message>
 </context>
 </TS>
